@@ -23,21 +23,25 @@ output_container = "output"
 
 
 class TaskResult:
-    def __init__(self, result, error_message, stack_trace):
+    def __init__(self, result, error_message, stack_trace, offset):
         self.result = result
         self.error_message = error_message
         self.stack_trace = stack_trace
+        self.offset = offset
 
     @staticmethod
     def create_from_request_entity(entity):
-        result, error, trace = None, None, None
+        result, error, trace, offset = None, None, None, None
         if 'Result' in entity:
             result = entity['Result']
         if 'Error' in entity:
             error = entity['Error']
         if 'StackTrace' in entity:
             trace = entity['StackTrace']
-        return TaskResult(result, error, trace)
+        if 'Offset' in entity:
+            offset = entity['Offset']
+        
+        return TaskResult(result, error, trace, offset)
 
     def to_json(self):
         json_response = {"Completed": False}
@@ -48,6 +52,8 @@ class TaskResult:
             json_response['Error'] = self.error_message
             json_response['StackTrace'] = self.stack_trace
             json_response['Completed'] = True
+        if self.offset:
+            json_response['Progress'] = self.offset
         return json_response
 
 
